@@ -2,7 +2,7 @@ package Yars;
 
 use strict;
 use warnings;
-use v5.10.1;
+use 5.010.1;
 use Mojo::Base 'Clustericious::App';
 use Yars::Routes;
 use Yars::Tools;
@@ -12,7 +12,7 @@ use Log::Log4perl qw(:easy);
 use Number::Bytes::Human qw( format_bytes parse_bytes );
 
 # ABSTRACT: Yet Another RESTful-Archive Service
-our $VERSION = '1.08'; # VERSION
+our $VERSION = '1.09'; # VERSION
 
 
 has secret => rand;
@@ -140,6 +140,7 @@ CONF2
 
 
 1;
+
 __END__
 =pod
 
@@ -149,7 +150,7 @@ Yars - Yet Another RESTful-Archive Service
 
 =head1 VERSION
 
-version 1.08
+version 1.09
 
 =head1 DESCRIPTION
 
@@ -309,11 +310,11 @@ L<Yars::Client>
 
 =head1 AUTHOR
 
-original author: Marty Brandon
+Original author: Marty Brandon
 
-current maintainer: Graham Ollis <plicease@cpan.org>
+Current maintainer: Graham Ollis E<lt>plicease@cpan.orgE<gt>
 
-contributors:
+Contributors:
 
 Brian Duggan
 
