@@ -1,11 +1,11 @@
 package Yars::Client;
 
 # ABSTRACT: Yet Another RESTful-Archive Service Client
-our $VERSION = '1.08'; # VERSION
+our $VERSION = '1.09'; # VERSION
 
 use strict;
 use warnings;
-
+use 5.010;
 use Clustericious::Client;
 use Clustericious::Client::Command;
 use Clustericious::Config;
@@ -20,7 +20,7 @@ use Digest::file qw/digest_file_hex/;
 use Data::Dumper;
 use IO::Uncompress::Gunzip qw(gunzip $GunzipError);
 use Number::Bytes::Human qw( format_bytes parse_bytes );
-use 5.10.0;
+use File::Temp qw( tempdir );
 
 route_doc upload   => "<filename>";
 route_doc content  => "<filename> <md5>";
@@ -72,6 +72,17 @@ sub new {
     return $self;
 }
 
+sub client {
+    my($self, $new) = @_;
+    
+    $new ? do { 
+        $new->max_redirects(30);
+        $new->connect_timeout(30);
+        $self->SUPER::client($new);
+        $new;
+    } : $self->SUPER::client;
+}
+
 sub _get_url {
 
     # Helper to create the Mojo URL objects
@@ -273,6 +284,7 @@ sub _all_hosts {
 
 sub upload {
     my $self = shift;
+    my $content = ref($_[-1]) eq 'SCALAR' ? pop : undef;
     my $filename = pop;
     my $nostash;
     if (@_) {
@@ -292,7 +304,17 @@ sub upload {
     }
 
     LOGDIE "file needed for upload" unless $filename;
-    $filename = File::Spec->rel2abs($filename);
+    if(defined $content) {
+        # intended mainly for testing only,
+        # may be ulsewise later
+        $filename = File::Spec->catfile( tempdir( CLEANUP => 1 ), $filename );
+        open my $fh, '>', $filename;
+        binmode $fh;
+        print $fh $$content;
+        close $fh;
+    } else {
+        $filename = File::Spec->rel2abs($filename);
+    }
     -r $filename or LOGDIE "Could not read " . $filename;
 
     # Don't read the file.
@@ -350,7 +372,8 @@ sub _rand_filename {
 
 sub send {
     my $self = shift;
-    my %args = $self->meta_for->process_args(@_);
+    my $meta = $self->meta_for;
+    my %args = $meta->process_args(@_);
     my $content = $args{content};
     my $filename = $args{name} || $self->_rand_filename;
     my $status = $self->put($filename, $content);
@@ -427,7 +450,7 @@ Yars::Client - Yet Another RESTful-Archive Service Client
 
 =head1 VERSION
 
-version 1.08
+version 1.09
 
 =head1 SYNOPSIS
 
@@ -488,15 +511,13 @@ Client for L<Yars>.
 
 L<yarsclient>, L<Clustericious::Client>
 
-=cut
-
 =head1 AUTHOR
 
-original author: Marty Brandon
+Original author: Marty Brandon
 
-current maintainer: Graham Ollis <plicease@cpan.org>
+Current maintainer: Graham Ollis E<lt>plicease@cpan.orgE<gt>
 
-contributors:
+Contributors:
 
 Brian Duggan
 
