@@ -2,12 +2,12 @@ package Yars::Command::yars_disk_scan;
 
 # PODNAME: yars_disk_scan
 # ABSTRACT: scan a disk for corruption and report corrupt files to stdout
-our $VERSION = '1.08'; # VERSION
+our $VERSION = '1.09'; # VERSION
 
 
 use strict;
 use warnings;
-use v5.10;
+use 5.010;
 use Clustericious::Config;
 use Log::Log4perl::CommandLine qw/:all/;
 use Clustericious::Log;
@@ -76,6 +76,7 @@ sub main {
 }
 
 1;
+
 __END__
 =pod
 
