@@ -2,12 +2,12 @@ package Yars::Command::yars_fast_balance;
 
 # PODNAME: yars_fast_balance
 # ABSTRACT: Fix all files
-our $VERSION = '1.08'; # VERSION
+our $VERSION = '1.09'; # VERSION
 
 
 use strict;
 use warnings;
-use v5.10;
+use 5.010;
 use Yars::Client;
 use Log::Log4perl qw(:levels);
 use Log::Log4perl::CommandLine ':all', ':loginit' => { level => $INFO };
@@ -136,6 +136,7 @@ sub main {
 }
 
 1;
+
 __END__
 =pod
 
