@@ -1,7 +1,7 @@
 package Yars::Routes;
 
 # ABSTRACT: set up the routes for Yars.
-our $VERSION = '1.08'; # VERSION
+our $VERSION = '1.09'; # VERSION
 
 
 use strict;
@@ -120,7 +120,8 @@ sub _head {
     my $dir = $c->tools->storage_path($md5);
     my $found_dir = -r "$dir/$filename" ? $dir : undef;
     $found_dir ||= $c->tools->local_stashed_dir( $filename, $md5 );
-    return $c->reply->not_found unless ( $found_dir or _redirect_to_remote_stash($c, $filename, $md5 ) );
+    return if _redirect_to_remote_stash($c, $filename, $md5 );
+    return $c->reply->not_found unless $found_dir;
     _set_static_headers($c,"$found_dir/$filename");
     $c->render( status => 200, text => 'found' );
 }
@@ -180,7 +181,7 @@ put '/file/#filename/:md5' => { md5 => 'calculate' } => sub {
     if ($c->req->headers->header('X-Yars-Stash')) {
         DEBUG "Stashing a file that is not ours : $digest $filename";
         _stash_locally($c, $filename, $digest, $asset) and return;
-        return $c->render_exception("Cannot stash $filename locally");
+        return $c->render->exception("Cannot stash $filename locally");
     }
 
     DEBUG "Received NoStash for $filename" if $c->req->headers->header('X-Yars-NoStash');
@@ -372,17 +373,23 @@ sub _del {
     if ($server eq $c->tools->server_url) {
         DEBUG "This is our file, we will delete it.";
         my $dir  = $c->tools->storage_path( $md5 );
-        if (-r "$dir/$filename" || ($dir = $c->tools->local_stashed_dir($filename,$md5))) {
-            unlink "$dir/$filename" or return $c->render_exception($!);
+        if (-r "$dir/$filename") {
+            unlink "$dir/$filename" or return $c->render->exception($!);
             $c->tools->cleanup_tree($dir);
             return $c->render(status => 200, text =>'ok');
         }
 
-        $server = $c->tools->remote_stashed_server($md5,$filename);
+        $server = $c->tools->remote_stashed_server($filename, $md5);
         return $c->reply->not_found unless $server;
         # otherwise fall through...
     }
 
+    if (my $dir = $c->tools->local_stashed_dir($filename,$md5)) {
+        unlink "$dir/$filename" or return $c->render->exception($!);
+        $c->tools->cleanup_tree($dir);
+        return $c->render(status => 200, text =>'ok');
+    }
+
     DEBUG "Proxying delete to $server";
     my $tx = $c->tools->_ua->delete("$server/file/$md5/$filename");
     if (my $res = $tx->success) {
@@ -391,7 +398,7 @@ sub _del {
         my $error = $tx->error;
         my ($msg,$code) = ($error->{message}, $error->{code});
         return $c->render(status => $code, text => $msg) if $code;
-        return $c->render_exception("Error deleting from $server ".format_tx_error($tx->error));
+        return $c->render->exception("Error deleting from $server ".format_tx_error($tx->error));
     }
 };
 
@@ -443,7 +450,7 @@ post '/disk/status' => sub {
     my $c = shift;
     my $got = $c->parse_autodata;
     my $root = $got->{root} || $got->{disk};
-    my $state = $got->{state} or return $c->render_exception("no state found in request");
+    my $state = $got->{state} or return $c->render->exception("no state found in request");
     my $server = $got->{server};
     if ($server && $server ne $c->tools->server_url) {
         unless ($c->tools->server_exists($server)) {
@@ -453,7 +460,7 @@ post '/disk/status' => sub {
         my $tx = $c->tools->_ua->post("$server/disk/status", $c->req->headers->to_hash, ''.$c->req->body );
         return $c->render_text( $tx->success ? $tx->res->body : 'failed '.format_tx_error($tx->error) );
     }
-    $c->tools->disk_is_local($root) or return $c->render_exception("Disk $root is not on ".$c->tools->server_url);
+    $c->tools->disk_is_local($root) or return $c->render->exception("Disk $root is not on ".$c->tools->server_url);
     my $success;
     for ($state) {
         /down/ and $success = $c->tools->mark_disk_down($root);
@@ -608,6 +615,7 @@ get '/bucket/usage' => sub {
 
 
 1;
+
 __END__
 =pod
 
@@ -617,7 +625,7 @@ Yars::Routes - set up the routes for Yars.
 
 =head1 VERSION
 
-version 1.08
+version 1.09
 
 =head1 ROUTES
 
@@ -677,11 +685,11 @@ L<Yars>, L<Yars::Client>
 
 =head1 AUTHOR
 
-original author: Marty Brandon
+Original author: Marty Brandon
 
-current maintainer: Graham Ollis <plicease@cpan.org>
+Current maintainer: Graham Ollis E<lt>plicease@cpan.orgE<gt>
 
-contributors:
+Contributors:
 
 Brian Duggan
 
