@@ -25,14 +25,14 @@ use Yars::Util qw( format_tx_error );
 
 
 # ABSTRACT: various utility functions dealing with servers, hosts, etc
-our $VERSION = '1.08'; # VERSION
+our $VERSION = '1.09'; # VERSION
 
 
 sub new
 {
   my($class, $config) = @_;
   WARN "No url found in config file" unless eval { $config->url };
-  bless {
+  my $self = bless {
     bucket_to_url                => { }, # map buckets to server urls
     bucket_to_root               => { }, # map buckets to disk roots
     disk_is_local                => { }, # our disk roots (values are just 1)
@@ -44,6 +44,8 @@ sub new
     server_status_cache_lifetime => 3,
     default_dir                  => '',
   }, $class;
+  $self->refresh_config($config);
+  $self;
 }
 
 sub _set_ua
@@ -56,13 +58,9 @@ sub _set_ua
 sub _ua
 {
   my($self) = @_;
-  
-  unless($self->{ua})
-  {
-    $self->{ua} = Mojo::UserAgent->new;
-  }
-  
-  return $self->{ua};
+  my $ua = $self->{ua} ? $self->{ua}->() : Mojo::UserAgent->new;
+  $ua->max_redirects(30);
+  $ua;
 }
 
 
@@ -426,6 +424,8 @@ sub b642hex {
 
 
 1;
+
+
 __END__
 =pod
 
@@ -435,7 +435,7 @@ Yars::Tools - various utility functions dealing with servers, hosts, etc
 
 =head1 VERSION
 
-version 1.08
+version 1.09
 
 =head1 DESCRIPTION
 
@@ -563,11 +563,11 @@ L<Yars>, L<Yars::Client>
 
 =head1 AUTHOR
 
-original author: Marty Brandon
+Original author: Marty Brandon
 
-current maintainer: Graham Ollis <plicease@cpan.org>
+Current maintainer: Graham Ollis E<lt>plicease@cpan.orgE<gt>
 
-contributors:
+Contributors:
 
 Brian Duggan
 
