@@ -6,7 +6,7 @@ use 5.010;
 use base qw( Exporter );
 
 # ABSTRACT: Yars internally used functions.
-our $VERSION = '1.08'; # VERSION
+our $VERSION = '1.09'; # VERSION
 
 our @EXPORT_OK = qw( format_tx_error );
 
@@ -26,6 +26,7 @@ sub format_tx_error
 }
 
 1;
+
 __END__
 =pod
 
@@ -35,7 +36,7 @@ Yars::Util - Yars internally used functions.
 
 =head1 VERSION
 
-version 1.08
+version 1.09
 
 =head1 FUNCTIONS
 
@@ -47,11 +48,11 @@ Formats a transaction error for human readable diagnostic.
 
 =head1 AUTHOR
 
-original author: Marty Brandon
+Original author: Marty Brandon
 
-current maintainer: Graham Ollis <plicease@cpan.org>
+Current maintainer: Graham Ollis E<lt>plicease@cpan.orgE<gt>
 
-contributors:
+Contributors:
 
 Brian Duggan
 
